@@ -89,7 +89,7 @@ add_account_to_provider (ProviderWidget *provider_widget)
                                         GTK_DIALOG_MODAL
                                         | GTK_DIALOG_DESTROY_WITH_PARENT
                                         | GTK_DIALOG_USE_HEADER_BAR,
-                                        NULL);
+                                        NULL, NULL);
 
   goa_provider_add_account (provider_widget->provider,
                             priv->goa_client,
@@ -102,7 +102,7 @@ add_account_to_provider (ProviderWidget *provider_widget)
 
   if (error) {
     if (!g_error_matches (error, GOA_ERROR, GOA_ERROR_DIALOG_DISMISSED))
-      g_warning ("fart %s\n", error->message);
+      g_warning ("fart %s", error->message);
     goto out;
   }
 
